Bring SETUP variable into game state block
[open-adventure.git] / init.c
diff --git a/init.c b/init.c
index 4af5ce9b61621cca9fd612ffc2d79801c65f6ba8..5425b7a0a15a4d615f1a08be86fec4b498e9b74d 100644 (file)
--- a/init.c
+++ b/init.c
@@ -15,7 +15,7 @@
  *     12600 words of message text (LINES, LINSIZ).
  *     885 travel options (TRAVEL, TRVSIZ).
  *     330 vocabulary words (KTAB, ATAB, TABSIZ).
*     185 locations (LTEXT, STEXT, KEY, COND, ABB, ATLOC, LOCSND, LOCSIZ).
  *     100 objects (PLAC, PLACE, FIXD, FIXED, LINK (TWICE), PTEXT, PROP,
  *                    OBJSND, OBJTXT).
  *      35 "action" verbs (ACTSPK, VRBSIZ).
@@ -186,7 +186,7 @@ static int finish_init(void) {
        } /* end loop */
 
        /* 1102 */ for (I=1; I<=LOCSIZ; I++) {
-       ABB[I]=0;
+       game.abbrev[I]=0;
        if(LTEXT[I] == 0 || KEY[I] == 0) goto L1102;
        K=KEY[I];
        if(MOD(labs(TRAVEL[K]),1000) == 1)COND[I]=2;
@@ -216,14 +216,14 @@ L1106:    /*etc*/ ;
 
 /*  Treasures, as noted earlier, are objects 50 through MAXTRS (CURRENTLY 79).
  *  Their props are initially -1, and are set to 0 the first time they are
*  described.  TALLY keeps track of how many are not yet found, so we know
  *  when to close the cave. */
 
        MAXTRS=79;
-       TALLY=0;
+       game.tally=0;
        for (I=50; I<=MAXTRS; I++) {
        if(PTEXT[I] != 0)PROP[I]= -1;
-       TALLY=TALLY-PROP[I];
+       game.tally=game.tally-PROP[I];
        } /* end loop */
 
 /*  Clear the hint stuff.  HINTLC(I) is how long he's been at LOC with cond bit
@@ -318,7 +318,7 @@ L1106:      /*etc*/ ;
  *  prior loc of each dwarf, initially garbage.  DALTLC is alternate initial loc
  *  for dwarf, in case one of them starts out on top of the adventurer.  (No 2
  *  of the 5 initial locs are adjacent.)  game.dseen is true if dwarf has seen him.
*  DFLAG controls the level of activation of all this:
  *     0       No dwarf stuff yet (wait until reaches Hall Of Mists)
  *     1       Reached Hall Of Mists, but hasn't met first dwarf
  *     2       Met first dwarf, others start moving, no knives thrown yet
@@ -333,7 +333,7 @@ L1106:      /*etc*/ ;
        for (I=1; I<=NDWARVES; I++) {
                game.dseen[I]=false;
        } /* end loop */
-       DFLAG=0;
+       game.dflag=0;
        game.dloc[1]=19;
        game.dloc[2]=27;
        game.dloc[3]=33;
@@ -350,49 +350,49 @@ L1106:    /*etc*/ ;
  *     game.conds      Min value for cond(loc) if loc has any hints
  *     game.detail     How often we've said "not allowed to give more detail"
  *     game.dkill      # of dwarves killed (unused in scoring, needed for msg)
*     FOOBAR  Current progress in saying "FEE FIE FOE FOO".
*     HOLDNG  Number of objects being carried
  *     IGO     How many times he's said "go XXX" instead of "XXX"
*     IWEST   How many times he's said "west" instead of "w"
*     KNFLOC  0 if no knife here, loc if knife here, -1 after caveat
*     LIMIT   Lifetime of lamp (not set here)
  *     MAXDIE  Number of reincarnation messages available (up to 5)
*     NUMDIE  Number of times killed so far
*     THRESH  Next #turns threshhold (-1 if none)
*     TRNDEX  Index in TRNVAL of next threshhold (section 14 of database)
*     TRNLUZ  # points lost so far due to number of turns used
*     TURNS   Tallies how many commands he's given (ignores yes/no)
  *     Logicals were explained earlier */
 
-       TURNS=0;
-       TRNDEX=1;
-       THRESH= -1;
-       if(TRNVLS > 0)THRESH=MOD(TRNVAL[1],100000)+1;
-       TRNLUZ=0;
-       LMWARN=false;
+       game.turns=0;
+       game.trndex=1;
+       game.thresh= -1;
+       if(TRNVLS > 0)game.thresh=MOD(TRNVAL[1],100000)+1;
+       game.trnluz=0;
+       game.lmwarn=false;
        IGO=0;
-       IWEST=0;
-       KNFLOC=0;
+       game.iwest=0;
+       game.knfloc=0;
        game.detail=0;
        game.abbnum=5;
        for (I=0; I<=4; I++) {
        {long x = 2*I+81; if(RTEXT[x] != 0)MAXDIE=I+1;}
        } /* end loop */
-       NUMDIE=0;
-       HOLDNG=0;
+       game.numdie=0;
+       game.holdng=0;
        game.dkill=0;
-       FOOBAR=0;
+       game.foobar=0;
        game.bonus=0;
        game.clock1=30;
        game.clock2=50;
        game.conds=SETBIT(11);
-       SAVED=0;
+       game.saved=0;
        game.closng=false;
-       PANIC=false;
+       game.panic=false;
        game.closed=false;
-       CLSHNT=false;
-       NOVICE=false;
-       SETUP=1;
+       game.clshnt=false;
+       game.novice=false;
+       game.setup=1;
        game.blklin=true;
 
        /* if we can ever think of how, we should save it at this point */
@@ -15,7 +15,7 @@
  *     885 travel options (TRAVEL, TRVSIZ).
  *     330 vocabulary words (KTAB, ATAB, TABSIZ).
- *     185 locations (LTEXT, STEXT, KEY, COND, ABB, ATLOC, LOCSND, LOCSIZ).
+ *     185 locations (LTEXT, STEXT, KEY, COND, abbrev, ATLOC, LOCSND, LOCSIZ).
  *     100 objects (PLAC, PLACE, FIXD, FIXED, LINK (TWICE), PTEXT, PROP,
  *                    OBJSND, OBJTXT).
@@ -216,14 +216,14 @@ L1106:    /*etc*/ ;
 /*  Treasures, as noted earlier, are objects 50 through MAXTRS (CURRENTLY 79).
  *  Their props are initially -1, and are set to 0 the first time they are
- *  described.  TALLY keeps track of how many are not yet found, so we know
+ *  described.  game.tally keeps track of how many are not yet found, so we know
  *  when to close the cave. */
 
@@ -318,7 +318,7 @@ L1106:      /*etc*/ ;
  *  for dwarf, in case one of them starts out on top of the adventurer.  (No 2
  *  of the 5 initial locs are adjacent.)  game.dseen is true if dwarf has seen him.
- *  DFLAG controls the level of activation of all this:
+ *  game.dflag controls the level of activation of all this:
  *     0       No dwarf stuff yet (wait until reaches Hall Of Mists)
  *     1       Reached Hall Of Mists, but hasn't met first dwarf
@@ -350,49 +350,49 @@ L1106:    /*etc*/ ;
  *     game.detail     How often we've said "not allowed to give more detail"
  *     game.dkill      # of dwarves killed (unused in scoring, needed for msg)
- *     FOOBAR  Current progress in saying "FEE FIE FOE FOO".
- *     HOLDNG  Number of objects being carried
+ *     game.foobar     Current progress in saying "FEE FIE FOE FOO".
+ *     game.holdng     Number of objects being carried
  *     IGO     How many times he's said "go XXX" instead of "XXX"
@@ -350,49 +350,49 @@ L1106:    /*etc*/ ;
  *     IGO     How many times he's said "go XXX" instead of "XXX"
- *     IWEST   How many times he's said "west" instead of "w"
- *     KNFLOC  0 if no knife here, loc if knife here, -1 after caveat
- *     LIMIT   Lifetime of lamp (not set here)
+ *     game.iwest      How many times he's said "west" instead of "w"
+ *     game.knfloc     0 if no knife here, loc if knife here, -1 after caveat
+ *     game.limit      Lifetime of lamp (not set here)
  *     MAXDIE  Number of reincarnation messages available (up to 5)
@@ -350,49 +350,49 @@ L1106:    /*etc*/ ;
  *     MAXDIE  Number of reincarnation messages available (up to 5)
- *     NUMDIE  Number of times killed so far
- *     THRESH  Next #turns threshhold (-1 if none)
- *     TRNDEX  Index in TRNVAL of next threshhold (section 14 of database)
- *     TRNLUZ  # points lost so far due to number of turns used
- *     TURNS   Tallies how many commands he's given (ignores yes/no)
+ *     game.numdie     Number of times killed so far
+ *     game.thresh     Next #turns threshhold (-1 if none)
+ *     game.trndex     Index in TRNVAL of next threshhold (section 14 of database)
+ *     game.trnluz     # points lost so far due to number of turns used
+ *     game.turns      Tallies how many commands he's given (ignores yes/no)
  *     Logicals were explained earlier */
 